pub struct StatFlags(/* private fields */);Expand description
Kernel flags for a process
See also the Stat::flags() method.
Implementations
Sourceimpl StatFlags
impl StatFlags
Sourcepub const PF_EXITING: StatFlags
pub const PF_EXITING: StatFlags
Getting shut down
Sourcepub const PF_EXITPIDONE: StatFlags
pub const PF_EXITPIDONE: StatFlags
PI exit done on shut down
Sourcepub const PF_WQ_WORKER: StatFlags
pub const PF_WQ_WORKER: StatFlags
I’m a workqueue worker
Sourcepub const PF_FORKNOEXEC: StatFlags
pub const PF_FORKNOEXEC: StatFlags
Forked but didn’t exec
Sourcepub const PF_MCE_PROCESS: StatFlags
pub const PF_MCE_PROCESS: StatFlags
Process policy on mce errors;
Sourcepub const PF_SUPERPRIV: StatFlags
pub const PF_SUPERPRIV: StatFlags
Used super-user privileges
Sourcepub const PF_DUMPCORE: StatFlags
pub const PF_DUMPCORE: StatFlags
Dumped core
Sourcepub const PF_SIGNALED: StatFlags
pub const PF_SIGNALED: StatFlags
Killed by a signal
Sourcepub const PF_MEMALLOC: StatFlags
pub const PF_MEMALLOC: StatFlags
Allocating memory
Sourcepub const PF_NPROC_EXCEEDED: StatFlags
pub const PF_NPROC_EXCEEDED: StatFlags
set_user() noticed that RLIMIT_NPROC was exceeded
Sourcepub const PF_USED_MATH: StatFlags
pub const PF_USED_MATH: StatFlags
If unset the fpu must be initialized before use
Sourcepub const PF_USED_ASYNC: StatFlags
pub const PF_USED_ASYNC: StatFlags
Used async_schedule*(), used by module init
Sourcepub const PF_NOFREEZE: StatFlags
pub const PF_NOFREEZE: StatFlags
This thread should not be frozen
Sourcepub const PF_MEMALLOC_NOFS: StatFlags
pub const PF_MEMALLOC_NOFS: StatFlags
All allocation requests will inherit GFP_NOFS
Sourcepub const PF_MEMALLOC_NOIO: StatFlags
pub const PF_MEMALLOC_NOIO: StatFlags
All allocation requests will inherit GFP_NOIO
Sourcepub const PF_LESS_THROTTLE: StatFlags
pub const PF_LESS_THROTTLE: StatFlags
Throttle me less: I clean memory
Sourcepub const PF_KTHREAD: StatFlags
pub const PF_KTHREAD: StatFlags
I am a kernel thread
Sourcepub const PF_RANDOMIZE: StatFlags
pub const PF_RANDOMIZE: StatFlags
Randomize virtual address space
Sourcepub const PF_SWAPWRITE: StatFlags
pub const PF_SWAPWRITE: StatFlags
Allowed to write to swap
Sourcepub const PF_MEMSTALL: StatFlags
pub const PF_MEMSTALL: StatFlags
Stalled due to lack of memory
Sourcepub const PF_NO_SETAFFINITY: StatFlags
pub const PF_NO_SETAFFINITY: StatFlags
Userland is not allowed to meddle with cpus_allowed
Sourcepub const PF_MCE_EARLY: StatFlags
pub const PF_MCE_EARLY: StatFlags
Early kill for mce process policy
Sourcepub const PF_MEMALLOC_NOCMA: StatFlags
pub const PF_MEMALLOC_NOCMA: StatFlags
All allocation request will have _GFP_MOVABLE cleared
Sourcepub const PF_MUTEX_TESTER: StatFlags
pub const PF_MUTEX_TESTER: StatFlags
Thread belongs to the rt mutex tester
Sourcepub const PF_FREEZER_SKIP: StatFlags
pub const PF_FREEZER_SKIP: StatFlags
Freezer should not count it as freezable
Sourcepub const PF_SUSPEND_TASK: StatFlags
pub const PF_SUSPEND_TASK: StatFlags
This thread called freeze_processes() and should not be frozen
Sourceimpl StatFlags
impl StatFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<StatFlags>
pub const fn from_bits(bits: u32) -> Option<StatFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> StatFlags
pub const fn from_bits_truncate(bits: u32) -> StatFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> StatFlags
pub const fn from_bits_retain(bits: u32) -> StatFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<StatFlags>
pub fn from_name(name: &str) -> Option<StatFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: StatFlags) -> bool
pub const fn intersects(&self, other: StatFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: StatFlags) -> bool
pub const fn contains(&self, other: StatFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: StatFlags)
pub fn remove(&mut self, other: StatFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: StatFlags)
pub fn toggle(&mut self, other: StatFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: StatFlags, value: bool)
pub fn set(&mut self, other: StatFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: StatFlags) -> StatFlags
pub const fn intersection(self, other: StatFlags) -> StatFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: StatFlags) -> StatFlags
pub const fn union(self, other: StatFlags) -> StatFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: StatFlags) -> StatFlags
pub const fn difference(self, other: StatFlags) -> StatFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: StatFlags) -> StatFlags
pub const fn symmetric_difference(self, other: StatFlags) -> StatFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> StatFlags
pub const fn complement(self) -> StatFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl StatFlags
impl StatFlags
Sourcepub const fn iter(&self) -> Iter<StatFlags>
pub const fn iter(&self) -> Iter<StatFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<StatFlags>
pub const fn iter_names(&self) -> IterNames<StatFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.