Struct procfs::LoadAverage
source · pub struct LoadAverage {
pub one: f32,
pub five: f32,
pub fifteen: f32,
pub cur: u32,
pub max: u32,
pub latest_pid: u32,
}Expand description
Load average figures.
Load averages are calculated as the number of jobs in the run queue (state R) or waiting for disk I/O (state D) averaged over 1, 5, and 15 minutes.
Fields
one: f32The one-minute load average
five: f32The five-minute load average
fifteen: f32THe fifteen-minute load average
cur: u32The number of currently runnable kernel scheduling entities (processes, threads).
max: u32The number of kernel scheduling entities that currently exist on the system.
latest_pid: u32The fifth field is the PID of the process that was most recently created on the system.
Implementations
sourceimpl LoadAverage
impl LoadAverage
sourcepub fn new() -> ProcResult<LoadAverage>
pub fn new() -> ProcResult<LoadAverage>
Reads load average info from /proc/loadavg