PhysicalPageFlags

Struct PhysicalPageFlags 

pub struct PhysicalPageFlags(/* private fields */);
Represents the fields and flags in a page table entry for a memory page.

Implementations

Source

impl PhysicalPageFlags

pub const LOCKED: PhysicalPageFlags

The page is being locked for exclusive access, e.g. by undergoing read/write IO

pub const ERROR: PhysicalPageFlags

IO error occurred

pub const REFERENCED: PhysicalPageFlags

The page has been referenced since last LRU list enqueue/requeue

pub const UPTODATE: PhysicalPageFlags

The page has up-to-date data. ie. for file backed page: (in-memory data revision >= on-disk one)

pub const DIRTY: PhysicalPageFlags

The page has been written to, hence contains new data. i.e. for file backed page: (in-memory data revision > on-disk one)

pub const LRU: PhysicalPageFlags

The page is in one of the LRU lists

pub const ACTIVE: PhysicalPageFlags

The page is in the active LRU list

pub const SLAB: PhysicalPageFlags

The page is managed by the SLAB/SLOB/SLUB/SLQB kernel memory allocator. When compound page is used, SLUB/SLQB will only set this flag on the head page; SLOB will not flag it at all

pub const WRITEBACK: PhysicalPageFlags

The page is being synced to disk

pub const RECLAIM: PhysicalPageFlags

The page will be reclaimed soon after its pageout IO completed

pub const BUDDY: PhysicalPageFlags

A free memory block managed by the buddy system allocator. The buddy system organizes free memory in blocks of various orders. An order N block has 2^N physically contiguous pages, with the BUDDY flag set for and only for the first page

pub const MMAP: PhysicalPageFlags

A memory mapped page

pub const ANON: PhysicalPageFlags

A memory mapped page that is not part of a file

pub const SWAPCACHE: PhysicalPageFlags

The page is mapped to swap space, i.e. has an associated swap entry

pub const SWAPBACKED: PhysicalPageFlags

The page is backed by swap/RAM

pub const COMPOUND_HEAD: PhysicalPageFlags

A compound page with order N consists of 2^N physically contiguous pages. A compound page with order 2 takes the form of “HTTT”, where H donates its head page and T donates its tail page(s). The major consumers of compound pages are hugeTLB pages (https://www.kernel.org/doc/html/latest/admin-guide/mm/hugetlbpage.html#hugetlbpage), the SLUB etc. memory allocators and various device drivers. However in this interface, only huge/giga pages are made visible to end users

pub const COMPOUND_TAIL: PhysicalPageFlags

A compound page tail (see description above)

pub const HUGE: PhysicalPageFlags

This is an integral part of a HugeTLB page

pub const UNEVICTABLE: PhysicalPageFlags

The page is in the unevictable (non-)LRU list It is somehow pinned and not a candidate for LRU page reclaims, e.g. ramfs pages, shmctl(SHM_LOCK) and mlock() memory segments

pub const HWPOISON: PhysicalPageFlags

Hardware detected memory corruption on this page: don’t touch the data!

pub const NOPAGE: PhysicalPageFlags

No page frame exists at the requested address

pub const KSM: PhysicalPageFlags

Identical memory pages dynamically shared between one or more processes

pub const THP: PhysicalPageFlags

Contiguous pages which construct transparent hugepages

pub const OFFLINE: PhysicalPageFlags

The page is logically offline

pub const ZERO_PAGE: PhysicalPageFlags

Zero page for pfn_zero or huge_zero page

pub const IDLE: PhysicalPageFlags

The page has not been accessed since it was marked idle (see https://www.kernel.org/doc/html/latest/admin-guide/mm/idle_page_tracking.html#idle-page-tracking). Note that this flag may be stale in case the page was accessed via a PTE. To make sure the flag is up-to-date one has to read /sys/kernel/mm/page_idle/bitmap first

pub const PGTABLE: PhysicalPageFlags

The page is in use as a page table

Source

impl PhysicalPageFlags

pub const fn empty() -> PhysicalPageFlags

Get a flags value with all bits unset.

pub const fn all() -> PhysicalPageFlags

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<PhysicalPageFlags>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> PhysicalPageFlags

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> PhysicalPageFlags

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<PhysicalPageFlags>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: PhysicalPageFlags) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: PhysicalPageFlags) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: PhysicalPageFlags)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: PhysicalPageFlags)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: PhysicalPageFlags)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: PhysicalPageFlags, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: PhysicalPageFlags) -> PhysicalPageFlags

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: PhysicalPageFlags) -> PhysicalPageFlags

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: PhysicalPageFlags) -> PhysicalPageFlags

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference( self, other: PhysicalPageFlags, ) -> PhysicalPageFlags

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> PhysicalPageFlags

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl PhysicalPageFlags

pub const fn iter(&self) -> Iter<PhysicalPageFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<PhysicalPageFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl PhysicalPageFlags